@@ -14,84 +14,15 @@ except:                     # pragma: no cover
 #from functools import wraps
 
 # External dependencies
-import webob
 from webob.exc import HTTPMethodNotAllowed, HTTPNotFound, HTTPInternalServerError
 
 # In-package dependencies
 from .exceptions import *
 from .matchers import *
+from .objects import *
 from .compat import *
 
 
-def get_func_attr(func, attr, default=None, delete=False):      # pragma: no cover
-    if sys.version_info[0] >= 3:
-        func_dict = func.__dict__
-    else:
-        func_dict = func.func_dict
-
-    if delete:
-        return func_dict.pop(attr, default)
-    else:
-        return func_dict.get(attr, default)
-
-def set_func_attr(func, attr, value):                           # pragma: no cover
-    if sys.version_info[0] >= 3:
-        func_dict = func.__dict__
-    else:
-        func_dict = func.func_dict
-
-    func_dict[attr] = value
-
-
-class Request(webob.BaseRequest):
-    """
-    Hoboken's request objects.  Uses WebOb's request object
-    """
-    @property
-    def is_safe(self):
-        """
-        Returns True if the request is considered "safe" - i.e. if the request
-        should be treated as not modifying any state.
-        """
-        return self.method in ['GET', 'HEAD', 'OPTIONS', 'TRACE']
-
-    @property
-    def is_idempotent(self):
-        """
-        Returns True if the request is considered idempotent - i.e. if two
-        successive identical requests should result in the same result.
-        """
-        return self.is_safe or self.method in ['PUT', 'DELETE']
-
-class Response(webob.Response):
-    """
-    Hoboken's request objects.  Uses WebOb's request object.
-    """
-    @property
-    def is_informational(self):
-        return 100 <= self.status_int <= 199
-
-    @property
-    def is_success(self):
-        return 200 <= self.status_int <= 299
-
-    @property
-    def is_redirect(self):
-        return 300 <= self.status_int <= 399
-
-    @property
-    def is_client_error(self):
-        return 400 <= self.status_int <= 499
-
-    @property
-    def is_server_error(self):
-        return 500 <= self.status_int <= 599
-
-    @property
-    def is_not_found(self):
-        return self.status_int == 404
-
-
 def condition(condition_func):
     def internal_decorator(func):
         # Either call the add_condition() func, or add this condition to the
@@ -127,7 +58,6 @@ def pass_route():
     raise ContinueRoutingException()
 
 
-
 class Route(object):
     """
     This class is an abstraction around a URL route.  It encapsulates:
